==> open_watcom_1.4.0-src.zip: bld/dwarf/dr/h/drinit.h <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  Initialization routines.
*
****************************************************************************/


dr_dbg_handle DRDbgInit( void *, unsigned long *, int );
dr_dbg_handle DRDbgInitNFT( void *, unsigned long *, int ); /* no file table */
void DRDbgFini( dr_dbg_handle );
extern dr_dbg_handle  DRSetDebug( dr_dbg_handle );
extern dr_dbg_handle  DRGetDebug();
extern int  DRDbgClear( dr_dbg_handle dbg );
extern void DRDbgDone( dr_dbg_handle dbg );
void DRInit( void );
void DRFini( void );
extern void DRDbgOldVersion( dr_dbg_handle dbg, int version );

==> open_watcom_1.7.1-src.zip: bld/dwarf/dr/h/drinit.h <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  Initialization routines.
*
****************************************************************************/


dr_dbg_handle DRDbgInit( void *, unsigned long *, int );
dr_dbg_handle DRDbgInitNFT( void *, unsigned long *, int ); /* no file table */
void DRDbgFini( dr_dbg_handle );
extern dr_dbg_handle  DRSetDebug( dr_dbg_handle );
extern dr_dbg_handle  DRGetDebug( void );
extern int  DRDbgClear( dr_dbg_handle dbg );
extern void DRDbgDone( dr_dbg_handle dbg );
void DRInit( void );
void DRFini( void );
extern void DRDbgOldVersion( dr_dbg_handle dbg, int version );
